<?php
namespace Teknisa\CTB\Controllers;

use Teknisa\CTB\Services\Ger06100ContaContabilService;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Request\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\ParameterBag;


class Ger06100ContaContabilController extends \Teknisa\CTB\Controllers\TeknisaCrud{

    protected $dataSourceName;
    protected $parameterBag;
    protected $crudService;
    protected $dataSourceNameToSave  = false;
    protected $service;

    public function __construct($crudService, ParameterBag $parameterBag, Ger06100ContaContabilService $service) {
        $this->service = $service;
        parent::__construct($crudService, $parameterBag);
    }

    public function verificaExclusao(DTO\Request $request, DTO\Response $response) {
        try {
    		$row   = $request->getRow();
    		$resul = $this->service->verificaExclusao($row);
            $dataSet = new DataSet("contctbl", $resul);
            $response->setDataSets(array($dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function salvarSubContas(DTO\Request $request, DTO\Response $response) {
        try {
    		$row   = $request->getRow();
    		$this->service->salvarSubContas($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function deletarSubContas(DTO\Request $request, DTO\Response $response) {
        try {
    		$row   = $request->getRow();
    		$this->service->deletarSubContas($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    public function verificaContaNivelAnterior(DTO\Request\Filter $request, DTO\Response $response) {
        try {
            $this->dataSourceName='contctbl';
            parent::find($request, $response);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function salvarContaContabil (DTO\Request $request, DTO\Response $response) {
        try {
    		$row   = $request->getRow();
    		$this->service->salvarContaContabil($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function salvarCadastramentoAutomatico (DTO\Request $request, DTO\Response $response) {
        try {
    		$row   = $request->getRow();
    		$this->service->salvarCadastramentoAutomatico($row);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    
    public function retornaMaiorConta(DTO\Request $request, DTO\Response $response) {
        try {
    		$row   = $request->getRow();
    		$resul = $this->service->retornaMaiorConta($row);
            $dataSet = new DataSet("contctbl", $resul);
            $response->setDataSets(array($dataSet));
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}
