<?php
namespace Teknisa\CTB\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\Libs\Util\NewCode;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\DateUtil;
use Teknisa\CTB\Factories\Ctb32700DREAnualFactory;

class Ctb32700DREAnualService {

    protected $entityManager;
    protected $newCode;
    protected $environment;
    protected $ctb32700DREAnualFactory;

    public function __construct(EntityManager $entityManager, Environment $environment, NewCode $newCode, Ctb32700DREAnualFactory $ctb32700DREAnualFactory) {
        $this->entityManager = $entityManager;
        $this->environment = $environment;
        $this->newCode = $newCode;
        $this->ctb32700DREAnualFactory = $ctb32700DREAnualFactory;
    }

    /**
     * Gera DRE Anual
     * @param $cdempresa
     * @param $dtctbinicial
     * @param $cdtipodemo
     * @param $cdfilial
     */
    public function geraDREAnual($cdempresa, $dtctbinicial, $cdtipodemo, $cdfilial) {
        $connection = $this->entityManager->getConnection();
        $connection->beginTransaction();
        try {
            
            // Variavel de Iniciação
            $vrtxadmcent = 0;
            $cdfilial = implode('_', $cdfilial);
            
            // Formata Data
            $dtinicial = "01/".$dtctbinicial;
            $dtfinal = DateUtil::truncateString(DateUtil::adicionaIntervalo($this->formataData($dtinicial), 11, "M"));
            
            // Gera Novo Código Lista
            $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrOrgTrab(), 1, 10);
            
            // Insere Lista
            $this->ctb32700DREAnualFactory->insereLista($nrlista, $cdfilial);
            $this->entityManager->flush();
            
            // Gera Novo Código DRE Gerencial
            $nrcontador = $this->newCode->getCodeByTableName('GERA_DREGERENCIAL', $this->environment->getNrOrgTrab(), 1, 10);
            
            // Executa Procedure GERA_DREGERENCIAL
            $nrcontabger = $this->ctb32700DREAnualFactory->geraDREAnual(
                $cdempresa, $nrlista, $cdtipodemo, $dtinicial, $dtfinal, $nrcontador, $vrtxadmcent
            );
            $this->entityManager->flush();
            
            /** @var Tmpcontabger $Tmpcontabger */
            $tmpcontabger = $this->ctb32700DREAnualFactory->buscaTmpcontabger($nrcontabger);
            if(!$tmpcontabger)
                throw new \Exception("Não há dados a serem listados.");
            
            $this->entityManager->flush();
            $connection->commit();
            
            return $nrcontabger;
        } catch (\Exception $e) {
            $connection->rollBack();
            throw $e;
        }
    }
    
    /**
     * Formata Data
     * @param $data
     * @return \DateTime|null|\Setforms2\Shared\ORM\DateTime|string
     */
    public function formataData($data){
        if (!$data)
            return null;

        if (strlen($data) == 19)
            $data = DateUtil::truncateString($data);
        $data = DateUtil::getDataDeString($data);
        $data = DateUtil::truncateData($data);

        return $data;
    }

}